#include <complex.h>

/* Maxwell-Garnett, J. C., 1904: Colours in metal glasses and
   metallic films. Philos. Trans. Roy. Soc., A203, 385-420. */

void
maxwell_garnett(float fraction, float refind_r_in, float refind_i_in,
		float* refind_r_out, float* refind_i_out)
{
  complex float refind_in = refind_r_in + I*refind_i_in;
  complex float eps_in = refind_in*refind_in;
  complex float eps_air = 1.0;
  //  complex float eps_out = eps_air + 2.0*fraction*eps_air*(eps_in-eps_air)
  //    / (eps_in + 2.0*eps_air - fraction*(eps_in - eps_air));
  complex float eps_out = eps_air + 3.0*fraction*eps_air*(eps_in-eps_air)
    / (eps_in + 2.0*eps_air - fraction*(eps_in - eps_air));
  complex refind_out = csqrt(eps_out);
  *refind_r_out = creal(refind_out);
  *refind_i_out = cimag(refind_out);
}
